StatefulFunctions
=================

Functions that depend for their computation on a `previous_value <StatefulFunction.previous_value>` attribute.

**Core class**:

* `StatefulFunction`

**Subtypes**:

.. toctree::
   :maxdepth: 1

   IntegratorFunctions
   MemoryFunctions